@@ -18,10 +18,8 @@ class IBClient:
             self.first_name: str = client_dict["first_name"]
             self.last_name: str = client_dict["last_name"]
             self.cpf: str = client_dict["cpf"]
-            self.birthday: datetime = IBUtil.date_from_iso_string(
-                client_dict["birthday"]
-            )
-            self.gender: str = client_dict["gender"]
+            self.birthday: datetime = IBUtil.date_from_iso_string(client_dict["birthday"]) if client_dict.get("birthday") else datetime.datetime.utcnow()
+            self.gender: str = client_dict.get("gender", "")
         else:
             self.company_name: str = client_dict["company_name"]
             self.fantasy_name: str = client_dict["fantasy_name"]
